pub struct CapabilityMatrix {
pub host: HostInfo,
pub targets: BTreeMap<TargetTriple, TargetInfo>,
}Expand description
Capability matrix for host/target combinations.
Fields
host: HostInfotargets: BTreeMap<TargetTriple, TargetInfo>Implementations
Sourceimpl CapabilityMatrix
impl CapabilityMatrix
Sourcepub fn new() -> Result<Self, HostDetectError>
pub fn new() -> Result<Self, HostDetectError>
Creates a new capability matrix for the current host.
Sourcepub fn assess(&mut self, target: &TargetTriple) -> &TargetInfo
pub fn assess(&mut self, target: &TargetTriple) -> &TargetInfo
Assesses a target and adds it to the matrix.
Sourcepub fn get(&mut self, target: &TargetTriple) -> &TargetInfo
pub fn get(&mut self, target: &TargetTriple) -> &TargetInfo
Gets the assessment for a target, computing it if necessary.
Sourcepub fn all_targets(&self) -> &BTreeMap<TargetTriple, TargetInfo>
pub fn all_targets(&self) -> &BTreeMap<TargetTriple, TargetInfo>
Returns all assessed targets.
Sourcepub fn is_native(&self, target: &TargetTriple) -> bool
pub fn is_native(&self, target: &TargetTriple) -> bool
Checks if a target can be built natively.
Sourcepub fn requires_cross(&self, target: &TargetTriple) -> bool
pub fn requires_cross(&self, target: &TargetTriple) -> bool
Checks if cross-compilation is required.
Sourcepub fn toolchain_hint(&mut self, target: &TargetTriple) -> ToolchainHint
pub fn toolchain_hint(&mut self, target: &TargetTriple) -> ToolchainHint
Gets the recommended toolchain provider for a target.
Sourcepub fn sysroot_hint(&mut self, target: &TargetTriple) -> SysrootHint
pub fn sysroot_hint(&mut self, target: &TargetTriple) -> SysrootHint
Gets the recommended sysroot provider for a target.
Sourcepub fn linker_hint(&mut self, target: &TargetTriple) -> LinkerHint
pub fn linker_hint(&mut self, target: &TargetTriple) -> LinkerHint
Gets the recommended linker for a target.